#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Django-audiofield is a Django application which allows audio file upload
and conversion to mp3, wav and ogg format.

It also makes it easy to play the audio files into your django application.

Project location : https://github.com/Star2Billing/django-audiofield
"""

__version__ = '0.6.6'  # edit also docs/source/conf.py and update requirements.txt
__author__ = "Areski Belaid"
__contact__ = "areski@gmail.com"
__homepage__ = "http://areskibelaid.com/"
__docformat__ = "restructuredtext"
